from numeronym.main import (
    Numeronym,
)
